#include <WiFi.h>
#include <WiFiUdp.h>
#include <ESP32Servo.h>

// ===== Wi‑Fi settings =====
const char* ssid     = "72girls";
const char* password = "Rimmaisbabe6969";

const unsigned int udpPort = 8888;
WiFiUDP udp;

// ===== Servo setup for right wheel =====
Servo rightServo;
const int servoPin = 5;  // Connect the right servo's signal here

void setup() {
  Serial.begin(115200);
  rightServo.attach(servoPin);
  
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while(WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("\nWiFi connected!");
  Serial.print("IP Address: ");
  Serial.println(WiFi.localIP());
  
  udp.begin(udpPort);
}

void loop() {
  // Listen for an incoming UDP packet
  int packetSize = udp.parsePacket();
  if (packetSize) {
    char packetBuffer[64];
    int len = udp.read(packetBuffer, sizeof(packetBuffer) - 1);
    if(len > 0) {
      packetBuffer[len] = '\0'; // Null–terminate the string
    }
    Serial.print("Received packet: ");
    Serial.println(packetBuffer);
    
    // Parse the UDP message, expected format: "xSpeed,ySpeed"
    int xSpeed = 0, ySpeed = 0;
    char *token = strtok(packetBuffer, ",");
    if (token != NULL) {
      xSpeed = atoi(token);
      token = strtok(NULL, ",");
      if (token != NULL) {
        ySpeed = atoi(token);
      }
    }
    
    Serial.print("xSpeed: ");
    Serial.print(xSpeed);
    Serial.print(" | ySpeed: ");
    Serial.println(ySpeed);
    
    // Differential mixing for the right wheel: rightSpeed = ySpeed - xSpeed
    int rightSpeed = ySpeed - xSpeed;
    rightSpeed = constrain(rightSpeed, -100, 100);
    
    // Map the computed speed to a servo angle.
    // Example mapping:
    //   rightSpeed =  100  -> servoAngle = 60° (full forward)
    //   rightSpeed =    0  -> servoAngle = 90° (neutral)
    //   rightSpeed = -100  -> servoAngle = 120° (full reverse)
    int servoAngle = map(rightSpeed, -100, 100, 120, 60);
    Serial.print("Computed rightSpeed: ");
    Serial.print(rightSpeed);
    Serial.print(" -> servoAngle: ");
    Serial.println(servoAngle);
    
    // Command the servo
    rightServo.write(servoAngle);
  }
  
  delay(50); // Small delay to prevent busy looping
}
