#include <Keyboard.h>
#include <Adafruit_DotStar.h>
#include <SPI.h>

#define NUM_LEDS 1  // Only one LED used
Adafruit_DotStar strip = Adafruit_DotStar(NUM_LEDS, DOTSTAR_BRG);

// Define sensor pins
const int paintButtonPin = 9;
const int tiltSensorPin  = 7;

// Variables for tilt sensor debouncing & shake detection
int tiltState = LOW;
int lastTiltState = LOW;
unsigned long tiltLastDebounceTime = 0;
unsigned long tiltDebounceDelay = 50;  // milliseconds

// Color cycle variable: 0 = Cyan, 1 = Magenta, 2 = Yellow
int currentColorIndex = 0;

void setup() {
  Keyboard.begin();
  
  pinMode(paintButtonPin, INPUT_PULLUP);
  pinMode(tiltSensorPin, INPUT_PULLUP);
  
  Serial.begin(57600);
  
  // Initialize DotStar LED and turn it off initially
  strip.begin();
  strip.show();
}

void loop() {
  // --- Paint button handling (pin 9) ---
  if (digitalRead(paintButtonPin) == LOW) {
    Keyboard.press(83); // Send key 'S'
    Serial.println("paint");
    delay(300);         // Delay to control repeat rate
  } else {
    Keyboard.release(83);
  }
  
  // --- Tilt sensor shake detection (pin 7) ---
  int tiltReading = digitalRead(tiltSensorPin);
  
  // If the reading has changed, reset the debounce timer:
  if (tiltReading != lastTiltState) {
    tiltLastDebounceTime = millis();
  }
  
  // If the reading has been stable for longer than the debounce delay:
  if ((millis() - tiltLastDebounceTime) > tiltDebounceDelay) {
    if (tiltReading != tiltState) {
      tiltState = tiltReading;
      // On rising edge, update the color cycle
      if (tiltState == HIGH) {
        currentColorIndex = (currentColorIndex + 1) % 3;
        Serial.print("Color changed to index: ");
        Serial.println(currentColorIndex);
      }
    }
  }
  lastTiltState = tiltReading;
  
  // --- Update LED color based on currentColorIndex ---
  switch (currentColorIndex) {
    case 0: // Cyan (desired RGB: 0,255,255)
      // With DOTSTAR_BRG, setPixelColor(0, 255, 0, 255) yields (R,G,B) = (0,255,255)
      strip.setPixelColor(0, 255, 0, 255);
      break;
    case 1: // Magenta (desired RGB: 255,0,255)
      // With DOTSTAR_BRG, setPixelColor(0, 255, 255, 0) yields (R,G,B) = (255,0,255)
      strip.setPixelColor(0, 255, 255, 0);
      break;
    case 2: // Yellow (desired RGB: 255,255,0)
      // With DOTSTAR_BRG, setPixelColor(0, 0, 255, 255) yields (R,G,B) = (255,255,0)
      strip.setPixelColor(0, 0, 255, 255);
      break;
  }
  strip.show();
}
